import React, { forwardRef, useEffect, useReducer, useState } from "react";
import {
  Animated,
  Easing,
  StyleSheet,
  View,
  Image,
  Dimensions,
} from "react-native";
import Colors from "../common/Colors";
import { ANIM_DURATION, ANIMATION_TRACK, OBJ_WIDTH } from "./StencilAnimation";
// const pi_pose_strip = require("../../images/pi_pose_strip.png");
const pi_pose_strip = {
  uri: "https://d2h44aw7l5xdvz.cloudfront.net/CRM/PRM/pi_car_new_black_strip.png",
};

const AnimationEaseLinear = forwardRef((props, recordRef) => {
  const anim = new Animated.Value(0);

  useEffect(() => {
    recordRef.current = startAnim;
    console.log("**** useEffect recordRef assigned");
  });

  const startAnim = () => {
    const animObj = Animated.timing(anim, {
      toValue: ANIMATION_TRACK,
      duration: ANIM_DURATION,
      useNativeDriver: true,
      easing: Easing.linear,
    });
    animObj.start(() => {
      console.log("*** startAnim animation finished");
      animObj.reset();
      if (props.onAnimationFinish) {
        console.log("*** startAnim before onAnimationFinish");
        props.onAnimationFinish();
        console.log("*** startAnim after onAnimationFinish");
      }
    });
  };
  return (
    <View style={styles.mainView}>
      <Image
        style={styles.poseImage}
        source={pi_pose_strip}
        resizeMode="stretch"
      />
      <Animated.View
        style={[styles.animView, { transform: [{ translateX: anim }] }]}
      />
    </View>
  );
});

const styles = StyleSheet.create({
  mainView: {
    flex: 1,
    height: "100%",
    zIndex: 250,
    marginTop: 0,
    width: "100%",
    position: "absolute",
    justifyContent: "flex-start",
    backgroundColor: "transparent",
  },
  animView: {
    height: "15%",
    borderWidth: 2,
    borderColor: Colors.digitYellow,
    borderRadius: 5,
    width: "10%",
    backgroundColor: "transparent",
    position: "absolute",
  },
  stencilStyle: {
    width: "100%",
    height: "100%",
  },
  poseImage: {
    width: "100%",
    height: "15%",
    backgroundColor: "white",
  },
});

export default AnimationEaseLinear;
