import React, { useEffect, useRef, useState } from "react";
import {
  BackHandler,
  SafeAreaView,
  StatusBar,
  StyleSheet,
  View,
  TouchableOpacity,
  Alert,
  Text,
} from "react-native";
const iOS = Platform.OS === "ios";
import Orientation from "react-native-orientation";
import { Spinner } from "react-native-digitcamera/src/common/ThemedComponents";
import Colors from "react-native-digitcamera/src/common/Colors";
import Icon from "react-native-vector-icons/MaterialCommunityIcons";

import {
  SCREEN_HEIGHT,
  SCREEN_WIDTH,
} from "react-native-digitcamera/src/common/Constants";
import VideoPlayer from "react-native-video-player";

const DemoVideo = ({ navigation, route }) => {
  const { videoUri, onSkip, onProceed, onSkipToVideoPI } = route.params;
  const [actionVisibility, setActionVisibility] = useState(true);
  var videoRef = useRef();

  useEffect(() => {
    console.log("**** DemoVideo useEffect: videoUri: " + videoUri);
    let Immersive = undefined;
    let restoreImmersive = undefined;
    if (!iOS) {
      Immersive = require("react-native-immersive").Immersive;
      Immersive.setImmersive(true);
      restoreImmersive = () => {
        __DEV__ && console.log("Immersive state changed!");
        Immersive.setImmersive(true);
      };
      Immersive.addImmersiveListener(restoreImmersive);
    }

    let unsubscribe = navigation.addListener("focus", () => {
      Orientation.lockToLandscapeLeft();
    });
    // disabled back handler
    const backHandler = BackHandler.addEventListener(
      "hardwareBackPress",
      () => {
        return true;
      }
    );

    const timer = setTimeout(() => {
      clearTimeout(timer);
      if (videoRef) {
        videoRef.pause();
      }
    }, 2000);

    return () => {
      if (Immersive !== undefined) {
        // Immersive.off();
        Immersive.removeImmersiveListener(restoreImmersive);
      }

      backHandler.remove();
      unsubscribe();
    };
  }, []);
  return (
    <SafeAreaView
      edges={iOS ? ["top", "bottom", "right"] : []}
      style={styles.safeArea}
    >
      <View style={styles.main}>
        <Spinner loading={false} />
        <StatusBar hidden={true} />
        <VideoPlayer
          ref={(p) => (videoRef = p)}
          video={{ uri: videoUri, cache: true }}
          videoHeight={SCREEN_HEIGHT}
          videoWidth={SCREEN_WIDTH}
          playInBackground={false}
          pauseOnPress={true}
          autoplay={true}
          disableSeek={false}
          style={styles.productImageStyle}
        ></VideoPlayer>
        {!actionVisibility && (
          <View style={[styles.skipView]}>
            <TouchableOpacity
              style={{ justifyContent: "flex-start", alignItems: "center" }}
              onPress={() => {
                //   if(onSkip){
                //     onSkip();
                // }
              }}
            >
              <Text style={styles.demoVideoText}>
                {"Watch How to do Pre-Inspection"}
              </Text>
            </TouchableOpacity>
            <TouchableOpacity
              style={{ justifyContent: "center", alignItems: "center" }}
              onPress={() => {
                /* @STARTRECORDING */
                if (onSkipToVideoPI) {
                  onSkipToVideoPI();
                  navigation.goBack();
                  return;
                }
                if (onProceed) {
                  onProceed();
                }
              }}
            >
              <Text style={styles.proceedText}>{"Skip >>"}</Text>
            </TouchableOpacity>
          </View>
        )}
        {actionVisibility && (
          <View style={[styles.payView]}>
            <TouchableOpacity
              style={{ justifyContent: "center", alignItems: "center" }}
              onPress={() => {
                //   if(onSkip){
                //     onSkip();
                // }
                setActionVisibility(false);
                if (videoRef) {
                  videoRef.resume();
                }
              }}
            >
              <Icon
                name="play-circle"
                size={48}
                color={Colors.digitYellow}
                style={{ backgroundColor: "transparent" }}
              />
              <Text style={styles.playVideoText}>
                {"Watch How to do Pre-Inspection"}
              </Text>
            </TouchableOpacity>
          </View>
        )}
      </View>
    </SafeAreaView >
  );
};
const styles = StyleSheet.create({
  safeArea: {
    flex: 1,
    backgroundColor: Colors.darkBlack,
  },
  main: {
    flex: 1,
    justifyContent: "flex-start",
  },
  productImageStyle: {
    height: "100%",
    width: "100%",
  },
  skipView: {
    position: "absolute",
    width: "100%",
    flexDirection: "column",
    height: "87%",
    justifyContent: "space-between",
    backgroundColor: "transparent",
  },
  payView: {
    position: "absolute",
    width: "100%",
    flexDirection: "column",
    height: "100%",
    justifyContent: "center",
    backgroundColor: "rgba(0, 0, 0, 0.8)",
  },
  demoVideoText: {
    backgroundColor: "transparent",
    fontFamily: "Muli-Bold",
    fontSize: 18,
    padding: 20,
    alignSelf: "flex-start",
    color: "white",
  },
  playVideoText: {
    backgroundColor: "transparent",
    fontFamily: "Muli-Bold",
    fontSize: 18,
    padding: 20,
    alignSelf: "center",
    color: "white",
  },
  proceedText: {
    backgroundColor: "transparent",
    fontFamily: "Muli-Bold",
    fontSize: 18,
    padding: 10,
    alignSelf: "flex-end",
    color: "white",
  },
});
export default DemoVideo;
