import React, { useEffect, useState } from "react";
import {
  View,
  Text,
  Image,
  StyleSheet,
  Alert,
  ActivityIndicator,
  Dimensions,
} from "react-native";
import style from "../../../../Components/common/CommonStyle";
import { PrimaryButton } from "react-native-digitcamera/src/common/ThemedComponents";
import Orientation from "../../../react-native-orientation";
import Database from "../../../../Components/common/Database";
import Colors from "react-native-digitcamera/src/common/Colors";
import Icon from "react-native-vector-icons/MaterialCommunityIcons";


/*
Import Modal from lib
add shouldHeaderVisible props
*/

/*
    Dimension issue fixed
*/

/* Get max dimension for screen width */

const getMinWidth = () => {
  return Math.round(
    Math.min(Dimensions.get("screen").height, Dimensions.get("screen").width)
  );
};
/*Initial SCREEN_WIDTH*/
let SCREEN_WIDTH = getMinWidth();

let realm = Database.getRealm();
var instructionInDb = realm.objects("PIVechicleInstruction");

console.log("^^^instruction data^^^", instructionInDb);

const DATA = [
  {
    instructionAssests: "https://d2h44aw7l5xdvz.cloudfront.net/CRM/PRM/open_bonnet.png",
    instructionTitle: "Open the car bonnet",
    instructionData: "Before we get started, please open up the car bonnet",
    okButtonText: "I have opened the bonnet",
  },
  {
    instructionAssests: "https://d2h44aw7l5xdvz.cloudfront.net/CRM/PRM/key_start.png",
    instructionTitle: "Start your vehicle",
    instructionData:
      "The engine should be ON for taking the odomenter reading & while recording the video.",
    okButtonText: "I have started the vehicle",
  },
  {
    instructionAssests: "https://d2h44aw7l5xdvz.cloudfront.net/CRM/PRM/chassis_find.png",
    instructionTitle: "Find your chassis number",
    instructionData:
      "Locate your chassis number, you can refer to the image to find chassis number.",
    okButtonText: "I have found the chassis number",
  },
];
const InstructionsScreen = (props) => {
  const [stepCount, setStepCount] = useState(0);
  const [instructionArr, setInstructionArr] = useState(
    JSON.parse(instructionInDb[0]?.instuction)
  );
  const [data, setData] = useState();
  const [imageLoaded, setImageLoaded] = useState(false);

  useEffect(() => {
    // if (Orientation.getInitialOrientation() === "PORTRAIT") {
    //     Orientation.lockToLandscape()
    // }
    Orientation.lockToLandscape()
    SCREEN_WIDTH = getMinWidth();

    // Comment this to enable local images

    // let item = instructionArr.find((item) => item.imageName === "VDO");

    // if (item !== undefined) {
    //   if (item.TSurveyInstructions.length !== 0) {
    //     setData(item.TSurveyInstructions)
    //   }
    // }

  }, [data]);

  const handleButtonPress = () => {
    /*
        stepCount refers to the number of steps 
        intialized as 0 for to act as index for 
        intstructions array.
        */
    if (stepCount < 2) {
      /*
            Loads next instructions
            */
      setStepCount(stepCount + 1);
      setImageLoaded(false);
    } else {
      /*
            startRecording callback
            */
      props.startRecording();
    }
  };

  const handleStepBack = () => {
    if (stepCount > 0) {
      setStepCount(stepCount - 1)
    }
  }

  const handleStepForward = () => {
    if (stepCount < 2) {
      setStepCount(stepCount + 1)
    }
  }

  return (
    <View style={styles.iSContainer}>
      <View style={styles.iSInstructionsContainer}>
        <View style={styles.iSImageContainer}>
          {/* Image Container */}
          <View style={styles.iSImageView}>
            <Image
              source={{ uri: data !== undefined ? data[stepCount].instructionAssests : DATA[stepCount].instructionAssests }}
              // source={{ uri: props.instructionAssests === undefined ? data[stepCount].instructionAssests : props.instructionAssests }}
              style={styles.iSImage}
              onLoad={() => setImageLoaded(true)}
            />

            {/* This indicator will show until image is fetched & displayed. */}
            {!imageLoaded && (
              <ActivityIndicator
                size="large"
                color={Colors.digitYellow}
                style={styles.iSFetchingImageIndicator}
              />
            )}
          </View>

          {/* Instructions Details & Action */}
          <View style={styles.iSInstructionsView}>
            {/* Instructions Steps,Title,Detailss */}
            <View style={styles.iSTitleDetailParent}>
              <View style={styles.iSStepTitle}>
                <View style={styles.iSStepAction}>
                  <Icon name="arrow-left" size={24} color={stepCount == 0 ? "transparent" : Colors.veryLightGray} onPress={handleStepBack} />
                  <Text style={[styles.iSCurrentStep, style.muliRegLG]}>
                    Step <Text>{stepCount + 1}/3</Text>
                  </Text>
                  <Icon name="arrow-right" size={24} color={stepCount == 2 ? "transparent" : Colors.veryLightGray} onPress={handleStepForward} />

                </View>
                <Text style={[style.muliBoldDB, styles.iSTitle]}>
                  {data !== undefined
                    ? data[stepCount].instructionTitle
                    : DATA[stepCount].instructionTitle}
                </Text>
              </View>
              <View style={styles.iSDetailsView}>
                <Text
                  style={[style.muliRegDB, styles.iSDetails]}
                  numberOfLines={6}
                >
                  {data !== undefined
                    ? data[stepCount].instructionData
                    : DATA[stepCount].instructionData}
                </Text>
              </View>
            </View>
            {/* Action Button */}
            <View style={styles.iSButtonView}>
              <PrimaryButton onPress={handleButtonPress}>
                {data !== undefined
                  ? data[stepCount].okButtonText
                  : DATA[stepCount].okButtonText}
              </PrimaryButton>
            </View>
          </View>
        </View>
      </View>
    </View>
  );
};

// iS = Instruction Screen
const styles = StyleSheet.create({
  iSContainer: {
    // flex: 1,
    justifyContent: "flex-end",
    backgroundColor: "transparent",
  },
  iSInstructionsContainer: {
    padding: 16,
    paddingTop: 8,
    // borderTopLeftRadius: 10,
    // borderTopRightRadius: 10,
    // elevation: 5,
    height: SCREEN_WIDTH * 0.75,
    // backgroundColor: 'white'
  },
  iSImageContainer: {
    flex: 1,
    flexDirection: "row",
    justifyContent: "space-between",
  },
  iSImageView: {
    flex: 0.5,
  },
  iSImage: {
    height: "100%",
    width: "100%",
    borderRadius: 10,
    resizeMode: "stretch"
  },
  iSInstructionsView: {
    flex: 0.45,
  },
  iSTitleDetailParent: {
    flex: 0.7,
  },
  iSStepTitle: {
    // flex: 0.4,
  },
  iSStepAction: {
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'space-between'
  }
  ,
  iSCurrentStep: {
    fontSize: 16,
  },
  iSTitle: {
    fontSize: 24,
    marginTop: 16,
  },
  iSDetailsView: {
    marginTop: 8,
    // flex: 0.6
    flexDirection: "row",
    flexShrink: 1,
  },
  iSDetails: {
    fontSize: 16,
    flexShrink: 1,
    // textAlign: 'justify'
  },
  iSButtonView: {
    flex: 0.3,
    justifyContent: "flex-end",
  },
  iSFetchingImageIndicator: {
    position: "absolute",
    alignSelf: "center",
    top: 0,
    bottom: 0,
  },
});

export default InstructionsScreen;
