import React, {
  forwardRef,
  useEffect,
  useReducer,
  useRef,
  useState,
} from "react";
import { Text, Easing, StyleSheet, View, Image, Alert } from "react-native";
import { async } from "validate.js";
import Colors from "../common/Colors";
import { SCREEN_HEIGHT } from "../common/Constants";
import Database from "../../../../Components/common/Database";
import { PrimaryButton, TextInput } from "../common/ThemedComponents";
import Orientation from "react-native-orientation";
import AnimationEaseLinear from "./AnimationEaseLinear";
import ViewShot, { captureRef } from "react-native-view-shot";
import UploadFile from "react-native-digitcamera/src/Screens/UploadFile";
import Modal from "../common/Modal";
import InstructionsScreen from "./InstructionsScreen";



const RCB1 = "RCB1",
  RCB2 = "RCB2",
  DBD = "DBD",
  VDO = "VDO";

export const NO_OF_POSES = 12;
export const OBJ_WIDTH = SCREEN_HEIGHT / NO_OF_POSES;
const newPosePeriod = SCREEN_HEIGHT / NO_OF_POSES;
export const ANIMATION_TRACK = SCREEN_HEIGHT - OBJ_WIDTH / 2;
export const ANIM_DURATION = 1.5 * 60 * 1000;
const STOP_RECORDING_INTERVAL = 1 * 20 * 1000;
export const DURATION_PERIOD = ANIM_DURATION / NO_OF_POSES;

var locationRetryCount = 0;
let realm = Database.getRealm();
var instructionInDb = realm.objects("PIVechicleInstruction");

export const StencilAnimation = forwardRef((props, cameraRef) => {
  const [easeAnimation, setEaseAnimation] = useState(false);
  const [startRecording, setStartRecording] = useState(false);
  const [enableStopVideoButton, setEnableStopVideoButton] = useState(false);
  var [currentLatitude, setCurrentLatitude] = useState("");
  var [currentLongitude, setCurrentLongitude] = useState("");
  const [imagePreview, setImagePreview] = useState(false);
  const [imagePreviewUri, setImagePreviewUri] = useState("");
  const [dateTime, setDateTime] = useState("");
  const [odometerReadings, setOdometerReadings] = useState("");
  const [instructionsModalVisible, setInstructionsModalVisible] =
    useState(false);
  const viewShotRef = useRef();
  // const [enableRCBPreview, setEnableRCBPreview] = useState(false);

  var dbInstr = instructionInDb[0]?.instuction;
  // if (__DEV__ && (dbInstr === undefined || dbInstr.length <= 0)) {
  //   console.log("**** dbInstruction not available taking hard coded");
  //   dbInstr = JSON.parse(
  //     '[{"surveyStepsId":1053,"createdDate":"Feb21,202012:15:05PM","isLast":false,"lastModifiedDate":"Feb21,202012:15:05PM","stepAssests":"https://cdn.godigit.com/digitEdgeAssets/Motor/4W_PI_RCB1_V2.jpg","stepStencilAssests":"","stepTitle":"RCBook","stepTitleHn":"आरसीबुक","imageName":"RCB1","displayOrder":160,"type":"image","TSurveyInstructions":[{"surveyInstructionsId":1740,"createdDate":"May18,202212:25:18PM","instructionData":"SendusapictureofthefrontofyourRCbook/card.","lastModifiedDate":"May18,202212:25:18PM","instructionTime":1,"instructionDataHn":"हमेंअपनेआरसीबुक/कार्डकेसामनेकीतस्वीरभेजें।","effectiveDate":"May18,202212:27:19PM"}],"effectiveDate":"May17,202203:18:48PM"},{"surveyStepsId":1056,"createdDate":"Feb21,202012:15:05PM","isLast":false,"lastModifiedDate":"Feb21,202012:15:05PM","stepAssests":"https://cdn.godigit.com/digitEdgeAssets/Motor/4W_PI_RCB2_V2.jpg","stepStencilAssests":"","stepTitle":"RCBook","stepTitleHn":"आरसीबुक","imageName":"RCB2","displayOrder":180,"type":"image","TSurveyInstructions":[{"surveyInstructionsId":1741,"createdDate":"May18,202212:25:18PM","instructionData":"SendusapictureofthebackofyourRCbook/card.","lastModifiedDate":"May18,202212:25:18PM","instructionTime":2,"instructionDataHn":"हमेंअपनेआरसीबुक/कार्डकेपीछेकीतस्वीरभेजें।","effectiveDate":"May18,202212:27:19PM"}],"effectiveDate":"May17,202203:18:48PM"},{"surveyStepsId":1054,"createdDate":"Feb21,202012:15:05PM","isLast":false,"descriptionHn":"फोटोलेतेसमयसुनिश्चितकरेंकिवाहनचालूहै","lastModifiedDate":"Feb21,202012:15:05PM","stepAssests":"https://cdn.godigit.com/digitEdgeAssets/Motor/MZBG2T7_Odometer-01_V2.jpg","stepStencilAssests":"","stepTitle":"Enterthevehicle,turnitonandtakeimagesofyourodometer","stepTitleHn":"गाड़ीमेंप्रवेशकरें,इसेचालूकरेंऔरअपनेओडोमीटरकेफ़ोटोलें","imageName":"DBD","displayOrder":200,"type":"image","TSurveyInstructions":[{"surveyInstructionsId":1742,"createdDate":"May18,202212:30:48PM","instructionData":"Entertheodometerreadingintheboxbelow\\r\\n\\r\\nNote:Odometerreadingindicatesthetotaldistancethevehiclehastraveled!Pleaseensurethereadingreflectsthatandisnotsettodisplaytripreading.","lastModifiedDate":"May18,202212:30:48PM","instructionTime":3,"instructionDataHn":"नीचेदिएगएबॉक्समेंओडोमीटररीडिंगदर्जकरें\\r\\n\\r\\nनोट:ओडोमीटररीडिंगगाड़ीकीकुलयात्रादूरीइंगितकरताहै!कृपयाध्यानरखेंकिरीडिंगप्रतिबिंबितकरतीहैऔरट्रिपरीडिंगप्रदर्शितकरनेकेलिएसेटनहींहै।","effectiveDate":"May18,202212:32:26PM"},{"surveyInstructionsId":1743,"createdDate":"May18,202212:30:48PM","instructionData":"Odometerreadingshouldbeclearlyvisible.","lastModifiedDate":"May18,202212:30:48PM","instructionTime":3,"instructionDataHn":"ओडोमीटररीडिंगस्पष्टरूपसेदिखाईदेनीचाहिए।","effectiveDate":"May18,202212:32:26PM"},{"surveyInstructionsId":1744,"createdDate":"May18,202212:30:48PM","instructionData":"Ensurethevehicleisturnedon","lastModifiedDate":"May18,202212:30:48PM","instructionTime":3,"instructionDataHn":"ध्यानरखेंकिगाड़ीचालूहै","effectiveDate":"May18,202212:32:26PM"},{"surveyInstructionsId":1745,"createdDate":"May18,202212:30:48PM","instructionData":"MakesuretheRPMindicator(asshownintheimage)isnotatzero","lastModifiedDate":"May18,202212:30:48PM","instructionTime":3,"instructionDataHn":"ध्यानरखेंकिआरपीएमइंडिकेटर(जैसाकिफ़ोटोमेंदिखायागयाहै)शून्यपरनहींहै","effectiveDate":"May18,202212:32:26PM"}],"effectiveDate":"May18,202212:21:56PM"},{"surveyStepsId":1057,"createdDate":"Feb21,202012:15:05PM","isLast":false,"lastModifiedDate":"Feb21,202012:15:05PM","stepAssests":"https://cdn.godigit.com/digitEdgeAssets/Motor/MZBG2T7_Odometer-01_V2.jpg","stepStencilAssests":"","stepTitle":"Starttheengine&makesureodometerreadingisvisible","imageName":"ODO","displayOrder":205,"type":"image","TSurveyInstructions":[],"effectiveDate":"May18,202212:21:56PM"},{"surveyStepsId":1058,"createdDate":"Feb21,202012:15:05PM","isLast":false,"lastModifiedDate":"Feb21,202012:15:05PM","stepAssests":"https://cdn.godigit.com/digitEdgeAssets/Motor/MZBG2T7_Odometer-01_V2.jpg","stepStencilAssests":"","stepTitle":"Openbonnetandlocateandchassisnumber","imageName":"CHP","displayOrder":210,"type":"image","TSurveyInstructions":[],"effectiveDate":"May18,202212:21:56PM"},{"surveyStepsId":1055,"createdDate":"Feb21,202012:15:05PM","description":"Shootvideofromadistancetocapturetheentirevehicle","isLast":false,"descriptionHn":"पूरीगाड़ीकोफ़ोकसकरनेकेलिएदूरसेवीडियोशूटकरें","lastModifiedDate":"Feb21,202012:15:05PM","stepAssests":"https://d2h44aw7l5xdvz.cloudfront.net/videos/self-inspection-for-car.mp4","stepStencilAssests":"","stepTitle":"Takea360°video","stepTitleHn":"360°वीडियोलें\\"","imageName":"VDO","displayOrder":220,"type":"video","TSurveyInstructions":[],"effectiveDate":"May18,202212:21:56PM"}]'
  //   );
  // } else {
  dbInstr = JSON.parse(dbInstr);
  // }
  var [instructionArr, setInstructionArr] = useState(dbInstr);
  const originalState = instructionArr[0];
  const [instructionManager, moveToNextStencil] = useReducer(
    reducer,
    originalState
  );
  var posePeriodInterval = useRef();
  var recordRef = useRef();
  function reducer(state = originalState, action) {
    let newState;
    switch (action.type) {
      case "init":
        console.log("***** reducer init: ");
        newState = instructionArr[0];
        break;
      case "next":
        const oldIndex = instructionArr.findIndex(
          (obj) => obj.displayOrder === state.displayOrder
        );
        const nextIndex = oldIndex + 1;
        console.log("***** reducer next " + nextIndex);
        const newInstruction = instructionArr[nextIndex];
        newState = newInstruction;
        break;
      case "prev":
        const oldPrevIndex = instructionArr.findIndex(
          (obj) => obj.displayOrder === state.displayOrder
        );
        const nextPrevIndex = oldPrevIndex - 1;
        console.log("***** reducer prev " + nextPrevIndex);
        newState = instructionArr[nextPrevIndex];
        break;
      case "toIndex": /* @DBD */
        newState = instructionArr[action.payload];
        break;
    }
    console.log("**** reducer returns: " + newState.imageName);
    return newState;
  }
  useEffect(() => {
    // if (instructionManager.displayOrder >= NO_OF_POSES - 1) {
    //   clearInterval(posePeriodInterval.current);
    // }
    getLatLong();
    getTime();
  }, [instructionManager]);


  /*@DBD*/
  useEffect(() => {
    if (props.nextDBD !== undefined && props.nextDBD) {
      setTimeout(() => {
        toIndex(2)
      }, 1)
    }
  }, [])

  useEffect(() => {
    Orientation.lockToLandscapeLeft();

    const myFun = async () => {
      await getInstructionsFromDb();
      posePeriodInterval.current = setInterval(() => {
        // nextStencil();
      }, DURATION_PERIOD);
    };
    myFun();
    return () => clearInterval(posePeriodInterval.current);
  }, []);
  const getInstructionsFromDb = async () => {
    let dbInstruction = instructionInDb[0]?.instuction;
    if (dbInstruction === undefined || dbInstruction.length <= 0) {
      props.navigation.navigate("WithQuote");
      Alert.alert(
        "Try Again!",
        "We are unable to load guiding information for you."
      );
      return;
    }
    instructionArr = dbInstruction;
    console.log("**** getInstructionFromDb: " + instructionArr);
    nextStencil("init");
  };
  const nextStencil = (instructionType = "next") => {
    moveToNextStencil({ type: instructionType });
  };

  const prevStencil = (instructionType = "prev") => {
    moveToNextStencil({ type: instructionType });
  };

  /* @DBD */
  const toIndex = (index) => {
    moveToNextStencil({ type: "toIndex", payload: index })
  }

  const imageInstructionTop = (instruction) => {
    return (
      <View style={styles.topInstructionView}>
        <Text style={styles.topInstructionText}>{instruction.stepTitle}</Text>
      </View>
    );
  };

  const instructionWithImage = (instruction) => {
    return (
      <View style={styles.instructionImageView}>
        {imageInstructionTop(instruction)}
        <Image
          key={instruction.displayOrder}
          style={styles.stencilStyle}
          resizeMode="stretch"
          source={{ uri: instruction.stepAssests }}
        />
        {true && (
          <TextInput
            returnKeyType="done"
            keyboardType={"number-pad"}
            style={{ flex: 0.2, marginHorizontal: 5, marginVertical: 5 }}
            label={"Enter Odometer Reading (in Km)"}
            value={"" + odometerReadings}
            onChangeText={(value) => {
              setOdometerReadings(value);
            }}
            errorMsge={""}
          />
        )}
        {imageInstructionBottom(instruction)}
      </View>
    );
  };

  const imageInstructionBottom = (instruction) => {
    return (
      <View style={styles.bottomInstructionView}>
        <Text style={styles.bottmInstructionText}>{instruction.stepTitle}</Text>
        <PrimaryButton
          style={styles.bottomInstructionButton}
          disabled={false}
          onPress={() => {
            getButtonAction(instruction)();
          }}
        >
          {getButtonName(instruction)}
        </PrimaryButton>
      </View>
    );
  };

  const onRetryCallback = (uri, DocumentImageName) => {
    if (
      DocumentImageName === RCB1 ||
      DocumentImageName === RCB2 ||
      DocumentImageName === DBD
    ) {
    } else if (DocumentImageName === VDO) {
    }
  };

  const onProceedCallback = (uri, DocumentImageName) => {
    if (
      DocumentImageName === RCB1 ||
      DocumentImageName === RCB2 ||
      DocumentImageName === DBD
    ) {
      console.log("**** ProceedCallback if UploadFile: " + DocumentImageName);
      UploadFile(uri, DocumentImageName, ".jpg", () => {
        props.navigation.navigate("WithQuote");
      });
      nextStencil("next");
    } else if (DocumentImageName === VDO) {
      // ***** IMPORTANT *******
      // this Logic is written in Camera.js
      // considering VDO is last file else we can check array[array.length-1] is last doc.
      console.log(
        "**** ProceedCallback else before UploadFile: " + DocumentImageName
      );
      props.navigation.navigate("VideoPIProgress");
      UploadFile(uri, DocumentImageName, ".jpg", () => {
        props.navigation.navigate("WithQuote");
      });
      console.log(
        "**** ProceedCallback after UploadFile: " + DocumentImageName
      );
      console.log(
        "**** ProceedCallback after navigate Progress: " + DocumentImageName
      );
    }
  };

  const goToPreviewMedia = (uri, documentImageName) => {
    props.navigation.navigate("PreviewMedia", {
      uri: uri,
      DocumentImageName: documentImageName,
      onRetry: onRetryCallback,
      onProceed: onProceedCallback,
    });
  };

  const getButtonAction = (instruction) => {
    if (instruction.imageName === RCB1 || instruction.imageName === RCB2) {
      const takeSnapshot = async () => {
        const options = {
          quality: 0.2,
          base64: true,
          orientation: "landscapeLeft",
        };
        console.log("*** takeSnapshot before takePictureAsync");
        const data = await props.myCamera.takePictureAsync(options);
        console.log("*** takeSnapshot after takePictureAsync: " + data.uri);
        setImagePreview(true);
        setImagePreviewUri(data.uri);
        // Alert.alert("Uri", data.uri);
        console.log("*** takeSnapshot before captureRef");
        const captureTimeout = setTimeout(() => {
          clearTimeout(captureTimeout);
          captureRef(viewShotRef, {
            format: "jpg",
            quality: 0.8,
          }).then(
            (uri) => {
              console.log("*** takeSnapshot in then captureRef: " + uri);
              setImagePreview(false);
              goToPreviewMedia(uri, instruction.imageName);
            },
            (error) => {
              console.log("*** takeSnapshot in error captureRef: " + error);
              // Alert.alert("ViewShot Uri Error", "" + error);
              setImagePreview(false);
            }
          );
        }, 700);
      };
      return takeSnapshot;
    } else if (instruction.imageName === VDO) {
      return stopScreenRecordingCallback;
    } else if (instruction.imageName === DBD) {
      const getODO = async () => {
        if (odometerReadings === undefined || odometerReadings.length <= 0) {
          Alert.alert("Enter valid readings");
          return;
        }
        savaDataToRealm(odometerReadings);
        /*@DEMOVIDEO*/

        /*Get Video URI*/
        const videoUri = instructionArr.find(item => item.imageName === "VDO")?.stepAssests
        /* pass next stencil as callback */
        props.navigation.navigate("DemoVideo", {
          onSkipToVideoPI: () => {
            callbackForNextStencil()
          },
          videoUri: videoUri
        })
        // nextStencil("next");
      };
      return getODO;
    }
    return () => {
      Alert.alert(
        "Oops!",
        "We are unable to take picture for " + instruction?.imageName
      );
    };
  };

  const callbackForNextStencil = () => {
    nextStencil("next")
  }

  const savaDataToRealm = (value) => {
    console.log("**** saveDataToRealm Odometer: " + value);
    realm.write(() => {
      console.log("**** saveDataToRealm before Odometer: " + value);
      realm.delete(realm.objects("PIOdometerData"));
      realm.create("PIOdometerData", {
        readings: value,
      });
    });
    console.log(
      "**** saveDataToRealm after Odometer: " +
      JSON.stringify(realm.objects("PIOdometerData"))
    );
  };

  const getButtonName = (instruction) => {
    if (instruction.imageName === RCB1 || instruction.imageName === RCB2) {
      return "Capture";
    } else if (instruction.imageName === VDO) {
      return "Stop Recording";
    } else if (instruction.imageName === DBD) {
      return "Submit";
    }
    return "Next";
  };

  const getLatLong = () => {
    const PILocation = realm.objects("PILocation");
    const latitude = PILocation[0]?.lat;
    const longitude = PILocation[0]?.long;
    if (
      locationRetryCount < 2 &&
      (latitude === undefined || longitude === undefined)
    ) {
      locationRetryCount += 1;
      Alert.alert(
        "Turn Off/On Location",
        "Oops! We are not able to fetch your location details. Please try again after turning Off and then On"
      );
      return;
    } else {
      setCurrentLatitude(latitude);
      setCurrentLongitude(longitude);
    }
  };

  // for gatting time
  const getTime = () => {
    const date = new Date().getDate();
    const month = new Date().getMonth() + 1;
    const year = new Date().getFullYear();

    //Time calulation for the display on preciew Screen
    const hour = new Date().getHours();
    const minute = new Date().getMinutes();
    const seconds = new Date().getSeconds();
    setDateTime(
      date +
      "/" +
      month +
      "/" +
      year +
      " - " +
      hour +
      ":" +
      minute +
      ":" +
      seconds
    );
  };

  // const rcbPreviewProceed = () => {
  //   setEnableRCBPreview(false);
  // };

  // /*@RCBPREVIEW*/
  // const goToRCBPreview = () => {
  //   return (
  //     <View
  //       style={{
  //         position: "absolute",
  //         zIndex: 400,
  //         width: "100%",
  //         height: "100%",
  //       }}
  //     >
  //       <RCBPreviewScreen proceedCallback={rcbPreviewProceed} />
  //     </View>
  //   );
  // };

  const instruction = (instruction) => {
    return (
      <View style={styles.instructionViewMain}>
        <View style={styles.dateTimeView}>
          <Text style={styles.instructionDateTimeText}>
            {"Lat:" +
              " " +
              currentLatitude +
              "  " +
              "Lon:" +
              "  " +
              currentLongitude +
              "  " +
              "    |    " +
              "Digit App" +
              "    |    " +
              dateTime}
          </Text>
        </View>
        <View style={styles.instructionView}>
          <Text style={styles.instructionText}>
            {instruction?.TSurveyInstructions[0]?.instructionData}
          </Text>
          <PrimaryButton
            style={styles.instructionButton}
            disabled={false}
            onPress={() => {
              getButtonAction(instruction)();
            }}
          >
            {getButtonName(instruction)}
          </PrimaryButton>
        </View>
      </View>
    );
  };

  const isInstructionWithImage = (instruction) => {
    if (instruction == undefined) {
      return false;
    }
    if (instruction.type === "input" || instruction.imageName === DBD) {
      return true;
    } else if (
      instruction.type === "image" &&
      (instruction.imageName === RCB1 || instruction.imageName === RCB2)
    ) {
      return false;
    } else {
      return false;
    }
  };

  const startVideo = async () => {
    if (props.startScreenRecording) {
      const res = await props.startScreenRecording();
      if (res && typeof recordRef.current === "function") {
        recordRef.current();
        console.log("**** startVideo Animation started");
      } else {
        Alert.alert("Recording Cancelled!");
      }
    }
  };

  const StartRecordingMainView = () => {
    return (
      <View style={styles.startRecordingView}>
        <View style={styles.startRecordingSubView}>
          <Text style={styles.textTitle}>
            Please be near engine number and chassis number
          </Text>
          <View style={styles.lineView} />
          <PrimaryButton
            style={styles.startRecordingButton}
            onPress={() => {
              /* @VEHICLEINSTRUCTIONS 
              instructions modal pops up
              on end of modal
              startVideo will execute
              */
              setEaseAnimation(true); // Logic to just change the status,
              setStartRecording(false);
              startVideo();
              // const stopVideoTimer = setTimeout(() => {
              //   clearTimeout(stopVideoTimer);
              //   setEnableStopVideoButton(true);
              // }, STOP_RECORDING_INTERVAL);
              // setEnableStopVideoButton(true);
            }}
          >
            {"Start Recording"}
          </PrimaryButton>
          <Text style={styles.textSubTitle}>
            Please note: once recording start, you'll have to complete whole
            recording as shown in demo pre-inspection video
          </Text>
        </View>
      </View>
    );
  };

  useEffect(() => {
    // if (instructionManager.imageName === RCB1) {
    //   setEnableRCBPreview(true);
    // } else {
    //   setEnableRCBPreview(false);
    // }
    if (instructionManager.imageName === VDO) {
      setStartRecording(true);
      setInstructionsModalVisible(true);
    } else {
      setStartRecording(false);
      setEaseAnimation(false);
      setInstructionsModalVisible(false);
    }
  }, [instructionManager.imageName]);

  const stopScreenRecordingCallback = async () => {
    // if (props.stopScreenRecording && enableStopVideoButton) {
    if (props.stopScreenRecording) {
      setStartRecording(true);
      await props.stopScreenRecording();
    } else {
      setEnableStopVideoButton(false);
      // show alert you can't stop
    }
  };

  const InstructionsScreenModal = () => {
    return (
      <View>
        <Modal
          isVisible={instructionsModalVisible}
          headerImageVisible={false}
          shouldHeaderVisible={false}
        >
          <InstructionsScreen
            startRecording={() => {
              setInstructionsModalVisible(false);
            }}
          />
        </Modal>
      </View>
    );
  };

  return (
    <ViewShot style={styles.mainView} ref={viewShotRef}>
      <View style={styles.mainView}>
        {easeAnimation && (
          <AnimationEaseLinear
            onAnimationFinish={stopScreenRecordingCallback}
            ref={recordRef}
          />
        )}
        {isInstructionWithImage(instructionManager) &&
          instructionWithImage(instructionManager)}
        {!isInstructionWithImage(instructionManager) &&
          instruction(instructionManager)}
        {/* {!isInstructionWithImage(instructionManager) &&
          enableRCBPreview &&
          goToRCBPreview(instructionManager)} */}
        {imagePreview && (
          <Image
            key={instructionManager.displayOrder}
            style={styles.previewImageView}
            resizeMode="cover"
            source={{ uri: imagePreviewUri }}
          />
        )}
        {startRecording && StartRecordingMainView()}
      </View>
      {instructionsModalVisible && InstructionsScreenModal()}
    </ViewShot>
  );
});

const styles = StyleSheet.create({
  mainView: {
    flex: 1,
    height: "100%",
    zIndex: 100,
    width: "100%",
    position: "absolute",
    backgroundColor: "transparent",
    justifyContent: "flex-end",
  },
  previewImageView: {
    position: "absolute",
    zIndex: 150,
    width: "100%",
    alignSelf: "center",
    height: "100%",
    backgroundColor: "transparent",
  },
  instructionImageView: {
    flex: 1,
    zIndex: 125,
    marginHorizontal: "20%",
    flexDirection: "column",
    justifyContent: "center",
    backgroundColor: "white",
  },
  stencilStyle: {
    flex: 0.6,
    width: "100%",
    alignSelf: "center",
    height: "100%",
    backgroundColor: "transparent",
  },
  instructionViewMain: {
    height: "25%",
    width: "100%",
    zIndex: 300,
    flexDirection: "column",
    justifyContent: "center",
    backgroundColor: "transparent",
  },
  dateTimeView: {
    flex: 0.4,
    height: "100%",
    width: "100%",
    flexDirection: "row",
    justifyContent: "flex-start",
    backgroundColor: "transparent",
  },
  instructionView: {
    flex: 0.8,
    height: "100%",
    width: "100%",
    flexDirection: "row",
    justifyContent: "flex-start",
    backgroundColor: "rgba(0,0,0,0.3)",
  },
  instructionText: {
    flex: 0.8,
    color: "white",
    alignSelf: "center",
    marginLeft: 10,
    fontFamily: "Muli-Bold",
    fontSize: 18,
  },
  instructionDateTimeText: {
    color: "white",
    marginLeft: 10,
    fontFamily: "Muli-Regular",
    fontSize: 18,
  },
  instructionButton: {
    flex: 0.2,
    height: "10%",
    marginRight: 10,
    alignSelf: "center",
  },
  bottomInstructionView: {
    flex: 0.2,
    height: "15%",
    width: "100%",
    flexDirection: "row",
    justifyContent: "center",
    backgroundColor: "white",
  },
  bottmInstructionText: {
    flex: 0.7,
    color: "black",
    alignSelf: "center",
    marginLeft: 10,
    fontFamily: "Muli-Bold",
  },
  bottomInstructionButton: {
    flex: 0.3,
    height: "10%",
    marginRight: 10,
    alignSelf: "center",
  },
  topInstructionView: {
    flex: 0.2,
    width: "100%",
    height: "100%",
    justifyContent: "center",
    backgroundColor: "white",
  },
  topInstructionText: {
    color: "black",
    alignSelf: "flex-start",
    marginLeft: 10,
    fontFamily: "Muli-Bold",
  },
  startRecordingView: {
    position: "absolute",
    zIndex: 400,
    width: "100%",
    height: "100%",
    justifyContent: "center",
    backgroundColor: "transparent",
  },
  startRecordingSubView: {
    width: "60%",
    height: "60%",
    alignSelf: "center",
    borderRadius: 10,
    justifyContent: "center",
    backgroundColor: "rgba(0, 0, 0, 0.8)",
  },
  textTitle: {
    color: "white",
    fontSize: 12,
    fontFamily: "Muli-Bold",
    paddingHorizontal: 10,
    alignSelf: "center",
  },
  textSubTitle: {
    color: Colors.inactiveText,
    fontSize: 10,
    fontFamily: "Muli-Regular",
    alignSelf: "center",
    paddingHorizontal: 10,
    marginVertical: 5,
  },
  lineView: {
    width: "80%",
    height: 0.5,
    marginVertical: 10,
    backgroundColor: Colors.inactiveText,
    alignSelf: "center",
  },
  startRecordingButton: {
    width: "50%",
    height: "10%",
    alignSelf: "center",
  },
});

export default {
  StencilAnimation,
  ANIM_DURATION,
  DURATION_PERIOD,
  NO_OF_POSES,
  OBJ_WIDTH,
  ANIMATION_TRACK,
};
