import React, { useEffect, useRef, useState } from "react";
import {
  StyleSheet,
  View,
  Image,
  Text,
  BackHandler,
  ScrollView,
  Alert,
  StatusBar,
  Platform,
} from "react-native";
import {
  SCREEN_HEIGHT,
  SCREEN_WIDTH,
} from "react-native-digitcamera/src/common/Constants";
import { translate } from "react-native-digitcamera/src/common/localize/i18n";
import Orientation from "../../../react-native-orientation";
import Geolocation from "@react-native-community/geolocation";
import { getTimeZone } from "react-native-localize";
import { TouchableOpacity } from "react-native-gesture-handler";
import RNFetchBlob from "rn-fetch-blob";
import { SELFSURVEYSERVICE_DOCUMENT_URL } from "react-native-digitcamera/src/Api/ApiUrls";
import ViewShot, { captureRef } from "react-native-view-shot";
import Carousel, { Pagination } from "react-native-snap-carousel";
import Header from "../Screens/Header";
import { PrimaryButton, Spinner } from "../common/ThemedComponents";
import Database from "../../../../Components/common/Database";
let realm = Database.getRealm();
import { measureConnectionSpeed } from "react-native-network-bandwith-speed";
import {
  ANDROID_REQUEST,
  WEB_REQUEST,
} from "react-native-digitcamera/lib/commonjs/common/Constants";
import { instructionData } from "react-native-digitcamera/src/common/Services/instruction";
import { dispatch } from "react-native-digitcamera/src/common/RootNavigation";
import {
  firebaseAttributes,
  errorRecord,
  firebaseEvents,
} from "../common/libEventLog/libCrashlytics/libCrashlyticsEvent";
import { async } from "validate.js";
import {
  startCapturingSensorData,
  cleanSensorDataArr,
  unsubscribeSensors,
} from "../common/SensorData";
import UserExperior from "react-native-userexperior/UserExperior";

const not_blur = require("../common/Image/not_blur.png");
const open_area_good_light = require("../common/Image/open_area_good_light.png");
const maintain_distance = require("../common/Image/maintain_distance.png");
const rc_book = require("../common/Image/rc_book.png");
const instruction = require("../common/Image/instruction.png");
const iOS = Platform.OS === "ios";

import {
  UELogEvent,
  UELogMessage,
} from "../common/libEventLog/UserExperior/LibUserExperior";
let instuction = [];
var activityId,
  activityTypeId,
  licensePlateNumber,
  toWithQuote,
  toTutorial,
  quoteNumber;
const Toturial = ({ navigation, route }) => {
  const nextcarousel = useRef();
  const [currentIndex, SetCurrentIndex] = useState(0);
  const [isLoading, SetIsLoading] = useState(true);
  const [, updateState] = React.useState();
  const forceUpdate = React.useCallback(() => updateState({}), []);
  const toturialData = [
    {
      image: open_area_good_light,
      heading: "Before recording the video please make sure :",
      subHeading: [
        { points: "Your vehicle is in an open space with good light" },
        { points: "Your vechicle is clean" },
        // { points: "Your device camera lens is clean" },
      ],
    },
    // {
    //   image: maintain_distance,
    //   heading: "While clicking the images, please make sure:",
    //   subHeading: [
    //     { points: "You maintain 4-5 feet distance from your vehicle" },
    //     { points: "Edges of the vehicle are also captured in the images" },
    //     { points: "Captured images are not blurred" },
    //   ],
    // },
    {
      image: rc_book,
      heading: "Keep the vehicle Registration Certificate (RC Book/Card) handy",
      subHeading: [],
    },
    {
      image: instruction,
      heading:
        "To help you click the correct image, simply refer to the image and instructions given at each step and you will be done in no time!",
      subHeading: [],
    },
  ];

  var DataSpeed;

  useEffect(() => {
    if (!iOS) {
      const Immersive = require("react-native-immersive").Immersive;
      Immersive.setImmersive(false);
    }
    StatusBar.setTranslucent(false);
    Orientation.lockToPortrait();

    var RealmData = realm.objects("PIVechicleData");
    (activityId = RealmData[0].activityId),
      (activityTypeId = RealmData[0].activityTypeId),
      (licensePlateNumber = RealmData[0].licensePlateNumber),
      (toWithQuote = RealmData[0].toWithQuote),
      (toTutorial = RealmData[0].toTutorial),
      (quoteNumber = RealmData[0].quoteNumber),
      console.log(
        "!!!!!!!!!!!!!!!!!!!!!!!!",
        activityId,
        activityTypeId,
        licensePlateNumber,
        toWithQuote,
        toTutorial,
        quoteNumber
      );

    getInstruction();

    let unsubscribe = navigation.addListener("focus", () => {
      Orientation.lockToPortrait();
    });
    saveToRealm();
    firebaseAttributes();
    return () => {
      unsubscribe();
      cleanSensorDataArr();
      unsubscribeSensors();
    };
  }, []);

  const saveToRealm = () => {
    try {
      realm.write(() => {
        realm.delete(realm.objects("PIRCBCount"));

        realm.create("PIRCBCount", {
          addMoreCount: 2,
        });
      });

      realm.write(() => {
        realm.delete(realm.objects("PIclickedCount"));

        realm.create("PIclickedCount", {
          clickedCount: 0,
        });
      });

      realm.write(() => {
        realm.delete(realm.objects("PIUploadedCount"));

        realm.create("PIUploadedCount", {
          uploadedCount: 0,
        });
      });
    } catch (error) {
      console.log("Error", error);
    }
  };

  // check type of request
  const instructionWebOrAndroid = (activityTypeId) => {
    activityTypeId = getActivityTypeIdIfSSL(activityTypeId);
    return activityTypeId == 6 ||
      activityTypeId == 7 ||
      activityTypeId == 8 ||
      activityTypeId == 9 ||
      activityTypeId == 10 ||
      activityTypeId == 11 ||
      activityTypeId == 15 ||
      activityTypeId == 31
      ? WEB_REQUEST
      : ANDROID_REQUEST;
  };

  // get ssl
  const getActivityTypeIdIfSSL = (activityTypeId) => {
    if (activityTypeId == 50) {
      // Used for SSL deeplink / mapping given by Gowtham
      activityTypeId = 5;
    } else if (activityTypeId == 49) {
      activityTypeId = 26;
    } else if (activityTypeId == 51) {
      activityTypeId = 30;
    }
    return activityTypeId;
  };

  const subscribeSensorData = () => {};

  // get vechicle instructions
  const getInstruction = async () => {
    try {
      UELogEvent("getInstruction Started..", {
        "Activity Type Id": activityTypeId,
      });
      let requestTypeName = instructionWebOrAndroid(activityTypeId);
      UELogMessage("Response from instructionWebOrAndroid", {
        "Request Type Name": JSON.stringify(requestTypeName),
      });
      let requestTypeValue;
      if (requestTypeName == WEB_REQUEST) {
        requestTypeValue = 1;
      } else {
        requestTypeValue = 0;
      }

      UELogEvent("instructionData service call started", {
        "Type Id": JSON.stringify(activityTypeId),
        "Request Value": JSON.stringify(requestTypeValue),
      });
      let V_instuction = await instructionData({
        typeId: activityTypeId,
        requestValue: requestTypeValue,
        activityId: activityId,
      });
      if (activityTypeId == 5) {
        // if(__DEV__){
        //   Alert.alert("We are using pre-defined data")
        // }
        V_instuction = JSON.parse(
          '{"videoInspectionResponse":{"blockedSource":{"type":"String","value":"NA","valueInfo":{}},"isEligible":{"type":"Boolean","value":true,"valueInfo":{}}},"surveyMasterId":32,"activityTypeId":5,"createdDate":"May 20, 2022 02:42:33 PM","description":"We have made this quick and simple","lastModifiedDate":"May 20, 2022 02:42:33 PM","noOfSteps":4,"title":"A few tips for your 4 wheeler video inspection","TSurveyInstructions":[{"surveyInstructionsId":1740,"createdDate":"May 18, 2022 12:25:18 PM","instructionData":"Send us a picture of the front of your RC book/card.","lastModifiedDate":"May 18, 2022 12:25:18 PM","instructionTime":1,"instructionDataHn":"हमें अपने आरसी बुक/ कार्ड के सामने की तस्वीर भेजें।","effectiveDate":"May 18, 2022 12:27:19 PM"},{"surveyInstructionsId":1741,"createdDate":"May 18, 2022 12:25:18 PM","instructionData":"Send us a picture of the back of your RC book/card.","lastModifiedDate":"May 18, 2022 12:25:18 PM","instructionTime":2,"instructionDataHn":"हमें अपने आरसी बुक/ कार्ड के पीछे की तस्वीर भेजें।","effectiveDate":"May 18, 2022 12:27:19 PM"},{"surveyInstructionsId":1744,"createdDate":"May 18, 2022 12:30:48 PM","instructionData":"Locate your chassis number, you can refer to the image to find chassis number.","lastModifiedDate":"May 18, 2022 12:30:48 PM","instructionTime":3,"instructionDataHn":"ध्यान रखें कि गाड़ी चालू है","effectiveDate":"May 18, 2022 12:32:26 PM","instructionTitle":"Find your chassis number","okButtonText":"I have found the chassis no.","instructionAssests":"https://cdn.godigit.com/digitEdgeAssets/Motor/MZBG2T7_Odometer-01_V2.jpg"},{"surveyInstructionsId":1743,"createdDate":"May 18, 2022 12:30:48 PM","instructionData":"The engine should be ON for taking the odomenter reading & while recording the video.","lastModifiedDate":"May 18, 2022 12:30:48 PM","instructionTime":3,"instructionDataHn":"ओडोमीटर रीडिंग स्पष्ट रूप से दिखाई देनी चाहिए।","effectiveDate":"May 18, 2022 12:32:26 PM","instructionTitle":"Start your vehicle","okButtonText":"I have started the vehicle","instructionAssests":"https://cdn.godigit.com/digitEdgeAssets/Motor/MZBG2T7_Odometer-01_V2.jpg"},{"surveyInstructionsId":1742,"createdDate":"May 18, 2022 12:30:48 PM","instructionData":"Before we get started, please open up the car bonnet","lastModifiedDate":"May 18, 2022 12:30:48 PM","instructionTime":3,"instructionDataHn":"नीचे दिए गए बॉक्स में ओडोमीटर रीडिंग दर्ज करें\\r\\n\\r\\nनोट: ओडोमीटर रीडिंग गाड़ी की कुल यात्रा दूरी इंगित करता है! कृपया ध्यान रखें कि रीडिंग प्रतिबिंबित करती है और ट्रिप रीडिंग प्रदर्शित करने के लिए सेट नहीं है।","effectiveDate":"May 18, 2022 12:32:26 PM","instructionTitle":"Open the car bonnet","okButtonText":"I have opened the Bonnet","instructionAssests":"https://cdn.godigit.com/digitEdgeAssets/Motor/MZBG2T7_Odometer-01_V2.jpg"}],"TSurveySteps":[{"surveyStepsId":1053,"createdDate":"Feb 21, 2020 12:15:05 PM","isLast":false,"lastModifiedDate":"Feb 21, 2020 12:15:05 PM","stepAssests":"https://cdn.godigit.com/digitEdgeAssets/Motor/4W_PI_RCB1_V2.jpg","stepStencilAssests":"","stepTitle":"RC Book","stepTitleHn":"आरसी बुक","imageName":"RCB1","displayOrder":160,"type":"image","TSurveyInstructions":[{"surveyInstructionsId":1740,"createdDate":"May 18, 2022 12:25:18 PM","instructionData":"Send us a picture of the front of your RC book/card.","lastModifiedDate":"May 18, 2022 12:25:18 PM","instructionTime":1,"instructionDataHn":"हमें अपने आरसी बुक/ कार्ड के सामने की तस्वीर भेजें।","effectiveDate":"May 18, 2022 12:27:19 PM"}],"effectiveDate":"Dec 17, 2022 03:18:48 PM"},{"surveyStepsId":1054,"createdDate":"Feb 21, 2020 12:15:05 PM","description":"The Odometer reading indicates the total distance the vehicle has travelled! Please ensure the reading reflects that and is not set to display trip reading","isLast":false,"descriptionHn":"ओडोमीटर रीडिंग इंगित करता है कि वाहन ने कितनी दूरी तय की है! कृपया सुनिश्चित करें कि रीडिंग यह दर्शाती है और ट्रिप रीडिंग प्रदर्शित करने के लिए सेट नहीं है","lastModifiedDate":"Feb 21, 2020 12:15:05 PM","stepAssests":"https://cdn.godigit.com/digitEdgeAssets/Motor/MZBG2T7_Odometer-01_V2.jpg","stepStencilAssests":"","stepTitle":"Please enter the odometer km reading","stepTitleHn":"कृपया ओडोमीटर किमी रीडिंग दर्ज करें","imageName":"DBD","displayOrder":205,"type":"input","TSurveyInstructions":[],"effectiveDate":"Dec 17, 2022 03:18:48 PM"},{"surveyStepsId":1055,"createdDate":"Feb 21, 2020 12:15:05 PM","description":"Shoot video from a distance to capture the entire vehicle","isLast":false,"descriptionHn":"पूरीगाड़ी को फ़ोकस करने के लिए दूर से वीडियो शूट करें","lastModifiedDate":"Feb 21, 2020 12:15:05 PM","stepAssests":"https://d2h44aw7l5xdvz.cloudfront.net/videos/self-inspection-for-car.mp4","stepStencilAssests":"","stepTitle":"Take a 360° video","stepTitleHn":"360 ° वीडियो लें \\"","imageName":"VDO","displayOrder":220,"type":"video","TSurveyInstructions":[{"surveyInstructionsId":1742,"createdDate":"May 18, 2022 12:30:48 PM","instructionData":"Before we get started, please open up the car bonnet","lastModifiedDate":"May 18, 2022 12:30:48 PM","instructionTime":3,"instructionDataHn":"नीचे दिए गए बॉक्स में ओडोमीटर रीडिंग दर्ज करें\\r\\n\\r\\nनोट: ओडोमीटर रीडिंग गाड़ी की कुल यात्रा दूरी इंगित करता है! कृपया ध्यान रखें कि रीडिंग प्रतिबिंबित करती है और ट्रिप रीडिंग प्रदर्शित करने के लिए सेट नहीं है।","effectiveDate":"May 18, 2022 12:32:26 PM","instructionTitle":"Open the car bonnet","okButtonText":"I have opened the Bonnet","instructionAssests":"https://cdn.godigit.com/digitEdgeAssets/Motor/MZBG2T7_Odometer-01_V2.jpg"},{"surveyInstructionsId":1743,"createdDate":"May 18, 2022 12:30:48 PM","instructionData":"The engine should be ON for taking the odomenter reading & while recording the video.","lastModifiedDate":"May 18, 2022 12:30:48 PM","instructionTime":3,"instructionDataHn":"ओडोमीटर रीडिंग स्पष्ट रूप से दिखाई देनी चाहिए।","effectiveDate":"May 18, 2022 12:32:26 PM","instructionTitle":"Start your vehicle","okButtonText":"I have started the vehicle","instructionAssests":"https://cdn.godigit.com/digitEdgeAssets/Motor/MZBG2T7_Odometer-01_V2.jpg"},{"surveyInstructionsId":1744,"createdDate":"May 18, 2022 12:30:48 PM","instructionData":"Locate your chassis number, you can refer to the image to find chassis number.","lastModifiedDate":"May 18, 2022 12:30:48 PM","instructionTime":3,"instructionDataHn":"ध्यान रखें कि गाड़ी चालू है","effectiveDate":"May 18, 2022 12:32:26 PM","instructionTitle":"Find your chassis number","okButtonText":"I have found the chassis no.","instructionAssests":"https://cdn.godigit.com/digitEdgeAssets/Motor/MZBG2T7_Odometer-01_V2.jpg"}],"effectiveDate":"Dec 17, 2022 03:18:48 PM"},{"surveyStepsId":1056,"createdDate":"Feb 21, 2020 12:15:05 PM","isLast":false,"lastModifiedDate":"Feb 21, 2020 12:15:05 PM","stepAssests":"https://cdn.godigit.com/digitEdgeAssets/Motor/4W_PI_RCB2_V2.jpg","stepStencilAssests":"","stepTitle":"RC Book","stepTitleHn":"आरसी बुक","imageName":"RCB2","displayOrder":180,"type":"image","TSurveyInstructions":[{"surveyInstructionsId":1741,"createdDate":"May 18, 2022 12:25:18 PM","instructionData":"Send us a picture of the back of your RC book/card.","lastModifiedDate":"May 18, 2022 12:25:18 PM","instructionTime":2,"instructionDataHn":"हमें अपने आरसी बुक/ कार्ड के पीछे की तस्वीर भेजें।","effectiveDate":"May 18, 2022 12:27:19 PM"}],"effectiveDate":"Dec 17, 2022 03:18:48 PM"}],"isWebRequest":2,"titleHn":"आपके 4 व्हीलर इंस्पेक्शन के लिए कुछ सुझाव","descriptionHn":"हमने इसे शीघ्र होने वाला और सरल बना दिया है फ़ोटोको क्लिक करने से पहले:"}'
        );
      }
      UELogMessage("Response from instruction data", {
        "Vehicle Instructions": JSON.stringify(V_instuction),
      });

      // DataSpeed = await measureConnectionSpeed();
      if (true) {
        // if (false) {
        instuction = [];
        console.log("**** instruction: before");
        V_instuction?.TSurveySteps.map((item) => {
          if (activityTypeId === 26) {
            /*adding stencil assets to instructions*/
            const stencilItem = V_instuction?.stencilAssets.find(
              (asset) => asset.poseName === item.imageName
            );
            console.log("^^^^^^^^ STENCIL ITEM OBJ........", stencilItem);
            if (stencilItem !== undefined) {
              const stencilAssetURI = stencilItem.stencilAssetLink;
              item["stepStencilAssests"] = stencilAssetURI;
            }
          }

          console.log("**** instruction: added");
          instuction.push(item);
        });
      } else {
        instuction = [];
        V_instuction?.TSurveySteps.map((item) => {
          if (item.imageName != "VDO") {
            instuction.push(item);
          }
        });
      }
      // sorting instructions
      instuction.sort((obj1, obj2) => {
        let id1 = obj1.displayOrder;
        let id2 = obj2.displayOrder;
        return id1 - id2;
      });

      // New requirement -> Video shoot should be bring to first
      // if (instuction.length > 0) {
      //   let vdoObj = instuction[instuction.length - 1];
      //   instuction.splice(0, 0, vdoObj);
      //   instuction.pop();
      // }

      realm.write(() => {
        realm.delete(realm.objects("PIVechicleInstruction"));
        realm.create("PIVechicleInstruction", {
          instuction: JSON.stringify(instuction),
        });
        var RealmInstructionData = realm.objects("PIVechicleInstruction");
        console.log(
          "^^^^^^^^^^^^^^^^^^^^^^^^^ ",
          JSON.parse(RealmInstructionData[0].instuction).length
        );
      });
      setTimeout(() => {
        SetIsLoading(false);
      }, 1000);
      UELogMessage("Instrutions Details", {
        "Request Type Value": JSON.stringify(requestTypeValue),
        "Activity Id": JSON.stringify(activityId),
        "Activity Type Id": JSON.stringify(activityTypeId),
      });
      firebaseEvents(
        "Instruction",
        { requestTypeValue: requestTypeValue },
        activityId,
        activityTypeId,
        ""
      );
    } catch (error) {
      UELogEvent("getInstructions stopped in catch", {
        Error: JSON.stringify(error),
      });
      firebaseAttributes(error);
      errorRecord(error);
      console.log("Error in Tutorial >>> ", error);
      Alert.alert("Please try again !!!");
      setTimeout(() => {
        SetIsLoading(false);
      }, 1000);
    }
  };

  /* @MOVETORCB */
  const moveToRCBPreview = () => {
    const rcbObj = instuction.find((element) => {
      return element.imageName.includes("RCB");
    });
    if (rcbObj) {
      console.log("^^^^^^^ moveToRCBPreview, rcbObj ^^^^^^^", rcbObj);
      navigation.navigate("RCBPreviewScreen", {
        proceedCallback: () => {
          moveNow();
        },
      });
    } else {
      /* Directly taking to enter odometer reading then show demo video */
      moveNow();
      /* if rcb is not required then move to video directly */
      // moveToCamera()
    }
  };

  const moveToCamera = () => {
    const demoVideoUriObj = instuction.find((element) => {
      return element.imageName === "VDO";
    });
    if (demoVideoUriObj) {
      const demoVideoUri = demoVideoUriObj?.stepAssests;
      console.log("*** moveToCamera demoVideoUri: " + demoVideoUri);
      navigation.navigate("DemoVideo", {
        videoUri: demoVideoUri,
        onSkip: () => {
          moveNow();
        },
        onProceed: () => {
          moveNow();
        },
      });
    }
  };

  const moveNow = () => {
    navigation.navigate("Camera", {
      activityId,
      activityTypeId,
      licensePlateNumber,
    });
  };

  const _renderToturial = ({ item, index }) => {
    return (
      <View style={{ margin: 24, flex: 1 }}>
        <ScrollView>
          {/* Image view */}
          <View style={styles.imageView}>
            <Image
              source={item.image}
              resizeMode="contain"
              style={{
                width: SCREEN_WIDTH - SCREEN_WIDTH * 0.5,
                height: SCREEN_WIDTH - SCREEN_WIDTH * 0.5,
                alignSelf: "center",
                resizeMode: "contain",
              }}
            />
          </View>
          {/* info View */}
          <View style={styles.InfoView}>
            <Text style={styles.headingText}>{translate(item.heading)}</Text>
            {item.subHeading?.map((item, index) => {
              return (
                <Text key={"" + index} style={styles.pointText}>
                  {"\u2022"}
                  {" " + item.points}
                </Text>
              );
            })}
          </View>
        </ScrollView>
        <View>
          <Pagination
            dotsLength={toturialData.length}
            activeDotIndex={index}
            containerStyle={{ alignContent: "flex-end" }}
            dotStyle={{
              width: 11,
              height: 6,
              borderRadius: 5,
              marginHorizontal: 6,
              backgroundColor: "#000000",
            }}
            inactiveDotStyle={{
              // Define styles for inactive dots here
              width: 6,
              height: 6,
              borderRadius: 5,
              marginHorizontal: 6,
              backgroundColor: "#DDDDDD",
            }}
            inactiveDotOpacity={0.4}
            inactiveDotScale={0.6}
          />
        </View>
      </View>
    );
  };
  return (
    <View style={styles.main}>
      <Spinner loading={isLoading} />
      <Header
        hideArrowBackButton={false}
        onlanguagechange={() => {
          forceUpdate();
        }}
        onbackPress={() => {
          try {
            console.log("navigation.canGoBack()", navigation.canGoBack());
            if (navigation.canGoBack()) {
              navigation.pop();
            } else {
              if (Platform.OS === "android") {
                Alert.alert("Close", "are you sure ?", [
                  {
                    text: "Yes",
                    onPress: () => {
                      BackHandler.exitApp();
                    },
                    style: "cancel",
                  },
                  {
                    text: "No",
                    onPress: () => {
                      console.log("on No pressed");
                    },
                  },
                ]);
              }
            }
          } catch (error) {}
        }}
      />

      <View style={{ flex: 0.9 }}>
        <Carousel
          ref={nextcarousel}
          data={toturialData}
          renderItem={_renderToturial}
          sliderWidth={SCREEN_WIDTH}
          itemWidth={SCREEN_WIDTH}
          autoplay={false}
          loop={false}
          onBeforeSnapToItem={(index) => {
            SetCurrentIndex(index);
          }}
        />
      </View>
      <View
        style={{
          marginLeft: 24,
          marginRight: 24,
          width: SCREEN_WIDTH - 48,
          height: 1,
          backgroundColor: "#F5F5F5",
        }}
      />
      {currentIndex == toturialData.length - 1 ? (
        <View
          style={{
            flex: 0.1,
            justifyContent: "center",
            marginLeft: 24,
            marginRight: 24,
          }}
        >
          <PrimaryButton
            onPress={() => {
              if (instuction === undefined || instuction.length <= 0) {
                Alert.alert(
                  "Oops! ",
                  "We are unable to fetch guiding instruction for you, please try again"
                );
                navigation.pop();
                return;
              }

              nextcarousel.current.snapToNext();
              if (currentIndex == toturialData.length - 1) {
                startCapturingSensorData();

                /*@OLDFLOW */
                console.log("^^^^^^^^ ACTIVITYTYPEID", activityTypeId);
                if (activityTypeId === 5) {
                  moveToRCBPreview();
                } else {
                  navigation.navigate("PI", {
                    activityId,
                    activityTypeId,
                    licensePlateNumber,
                  });
                }
              }
              Orientation.lockToLandscapeLeft();
            }}
          >
            {"I understand"}
          </PrimaryButton>
        </View>
      ) : (
        <View style={styles.buttonView}>
          <View style={{ flex: 0.5, justifyContent: "center" }}>
            <TouchableOpacity
              onPress={() => {
                console.log("**** instuction " + instuction.length);
                if (instuction === undefined || instuction.length <= 0) {
                  Alert.alert(
                    "Oops! ",
                    "We are unable to fetch guiding instruction for you, please try again"
                  );
                  navigation.pop();
                  return;
                }

                startCapturingSensorData();
                /*@OLDFLOW */
                console.log(
                  "^^^^^^^ ACTIVITY TYPE ID ^^^^^^^^",
                  activityTypeId
                );
                if (activityTypeId === 5) {
                  moveToRCBPreview();
                } else {
                  navigation.navigate("PI", {
                    activityId,
                    activityTypeId,
                    licensePlateNumber,
                  });
                }
                Orientation.lockToLandscapeLeft();
                firebaseEvents(
                  "skip_Tutorial_clicked",
                  "",
                  activityId,
                  activityTypeId,
                  ""
                );
              }}
            >
              <Text
                style={{
                  fontFamily: "Muli-Black",
                  fontSize: 14,
                  color: "#FFAA00",
                  alignSelf: "center",
                }}
              >
                {translate("SKIP TUTORIAL")}
              </Text>
            </TouchableOpacity>
          </View>
          <View style={{ flex: 0.5, justifyContent: "center" }}>
            <PrimaryButton
              onPress={() => {
                if (instuction === undefined || instuction.length <= 0) {
                  Alert.alert(
                    "Oops! ",
                    "We are unable to fetch guiding instruction for you, please try again"
                  );
                  navigation.pop();
                  return;
                }

                nextcarousel.current.snapToNext();
                if (currentIndex == toturialData.length - 1) {
                  startCapturingSensorData();
                  moveToCamera();
                  Orientation.lockToLandscapeLeft();
                  firebaseEvents(
                    "start_clicked",
                    "",
                    activityId,
                    activityTypeId,
                    ""
                  );
                }
              }}
            >
              {currentIndex == toturialData.length - 1
                ? translate("Start")
                : translate("Next")}
            </PrimaryButton>
          </View>
        </View>
      )}
    </View>
  );
};
export default Toturial;

const styles = StyleSheet.create({
  main: {
    flex: 1,
    backgroundColor: "#FFFFFF",
  },
  imageView: {
    flex: 0.6,
    justifyContent: "center",
  },
  InfoView: {
    flex: 0.4,
  },
  headingText: {
    fontFamily: "Muli-Bold",
    fontSize: 20,
    marginBottom: 16,
    marginTop: 24,
  },
  pointText: {
    fontSize: 18,
    fontFamily: "Muli-Regular",
    lineHeight: 30,
  },
  buttonView: {
    flex: 0.1,
    marginLeft: 24,
    marginRight: 24,
    justifyContent: "center",
    flexDirection: "row",
  },
});
