import React, { useEffect, useState } from "react";
import { StyleSheet, View, Image, Text, BackHandler } from "react-native";
import { translate } from "react-native-digitcamera/src/common/localize/i18n";
import { ProgressBar } from "react-native-paper";
import reactotron from "reactotron-react-native";
import Header from "./Header";
import Orientation from "../../../react-native-orientation";
import { useSelector } from "react-redux";
import {
    UELogEvent,
    UELogMessage,
} from "../common/libEventLog/UserExperior/LibUserExperior";
import Database from "../../../../Components/common/Database";
let realm = Database.getRealm();
var PIVechicleData = realm.objects("PIVechicleData");
var uploadedImageCount = 0;
var uploadedImages = [];
var totalImages = 0;
var uploadedInterval;
const VideoPIProgress = ({ navigation, route }) => {
    const [, updateState] = React.useState();
    const forceUpdate = React.useCallback(() => updateState({}), []);
    const [docProgress, setDocProgress] = useState(0);
    var activityId = PIVechicleData[0]?.activityId;
    useEffect(() => {
        uploadedInterval = setInterval(() => {
            const completedCount = realm.objects("PIVideoCompleteStatus")[0]
                ?.completePercentage;
            setDocProgress(completedCount);
            console.log("**** uploadedInterval progress: " + completedCount);
            const mediaStatusObjs = realm.objects("PIMediaStatus");
            console.log(
                "**** Progress mediaStatusObjs: " + JSON.stringify(mediaStatusObjs)
            );
            totalImages = mediaStatusObjs.length;
            console.log("**** Progress totalImages: " + totalImages);

            uploadedImages = [];
            mediaStatusObjs.filter((item) => {
                if (item?.status === "uploaded") {
                    uploadedImages.push(item);
                }
            });
            console.log("**** Progress uploadedImages: " + uploadedImages.length);

            uploadedImageCount = uploadedImages.length;
        }, 1000);

        const backHandler = BackHandler.addEventListener(
            "hardwareBackPress",
            () => {
                return true;
            }
        );

        return () => {
            backHandler.remove();
        };
    }, []);

    const navigateTOthankYou = () => {
        const interval = setInterval(() => {
            if (uploadedImageCount >= totalImages) {
                if (docProgress >= 100) {
                    clearInterval(interval);
                    clearInterval(uploadedInterval);
                    navigation.navigate("ThankYou", { activityId: activityId });
                }
            }
        }, 1000);
    };

    return (
        <View style={styles.main}>
            <Header
                onlanguagechange={() => {
                    forceUpdate();
                }}
                onbackPress={() => {
                    navigation.goBack();
                }}
            />
            {/* GIF view */}
            <View style={styles.gifView}>
                <Image
                    source={{
                        uri: "https://d2h44aw7l5xdvz.cloudfront.net/assets/gif/time-animation-loader.gif",
                    }}
                    style={{ width: 146, height: 146, alignSelf: "center" }}
                />
            </View>
            {/* Progress View */}
            <View style={styles.progressView}>
                <Text style={styles.processingText}>
                    {"Uploading Video" + " "}
                    {docProgress + "%"}
                </Text>
                <ProgressBar
                    progress={docProgress * 0.01}
                    color={"#FFBB00"}
                    style={{ height: 12, borderRadius: 6, backgroundColor: "#F5F5F5" }}
                />
                {navigateTOthankYou()}
            </View>
        </View>
    );
};
const styles = StyleSheet.create({
    main: {
        flex: 1,
        backgroundColor: "#FFFFFF",
    },
    gifView: {
        flex: 0.5,
        justifyContent: "flex-end",
        marginBottom: 40,
        marginLeft: 24,
        marginRight: 24,
    },
    progressView: {
        flex: 0.5,
        marginLeft: 24,
        marginRight: 24,
    },
    processingText: {
        fontFamily: "Muli-Bold",
        fontSize: 20,
        alignSelf: "center",
        marginBottom: 15,
    },
});
export default VideoPIProgress;
